PySkein 0.5.2 — PySkein v0.5.2 documentation

### Navigation

- index
- next |
- PySkein v0.5.2 documentation »

# PySkein 0.5.2

PySkein is an extension module for Python 3.0 or later, allowing Python scripts to compute hash values with the recently proposed Skein hash algorithm (one of the Second Round Candidates in the NIST SHA-3 Competition). It is based on the optimized version of the Skein reference implementation, written in C by Doug Whiting. This guarantees efficient hashing (373 MB/s for Skein-512-512 called from Python on a 2.8 GHz Opteron).

- Computing Skein hashes
  - Examples

- Threefish encryption
  - Examples

- Pseudorandom Number Generator

- Demo Scripts
  - skeinsum
  - threefish

- Download PySkein
  - Changes
  - Previous versions

### Navigation

- index
- next |
- PySkein v0.5.2 documentation »